package com.ruoyi.models.mapper;

import java.util.List;

import com.ruoyi.models.domain.BizModule;

/**
 * 模块Mapper接口
 *
 * @author ruoyi
 * @date 2025-08-28
 */
public interface BizModuleMapper {
    /**
     * 查询模块
     *
     * @param moduleId 模块主键
     * @return 模块
     */
    public BizModule selectBizModuleByModuleId(Long moduleId);

    /**
     * 查询模块列表
     *
     * @param bizModule 模块
     * @return 模块集合
     */
    public List<BizModule> selectBizModuleList(BizModule bizModule);

    /**
     * 新增模块
     *
     * @param bizModule 模块
     * @return 结果
     */
    public int insertBizModule(BizModule bizModule);

    /**
     * 修改模块
     *
     * @param bizModule 模块
     * @return 结果
     */
    public int updateBizModule(BizModule bizModule);

    /**
     * 删除模块
     *
     * @param moduleId 模块主键
     * @return 结果
     */
    public int deleteBizModuleByModuleId(Long moduleId);

    /**
     * 批量删除模块
     *
     * @param moduleIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteBizModuleByModuleIds(Long[] moduleIds);



    public List<BizModule> selectByProjectId(long projectId);

    /**
     * 更新指派用户
     * @param bizModule 模块信息
     * @return 结果
     */
    public int updateDesignatedUser(BizModule bizModule);

    /**
     * 查询用户被指派的模块列表
     * @param userId 用户ID
     * @return 模块集合
     */
    public List<BizModule> selectAssignedModules(Long userId);
}
